@@ -11,7 +11,7 @@
 
 #include <math.h>
 #include <stdlib.h>
-#include <pango/pangocairo.h>
+#include <pango2/pangocairo.h>
 
 void fancy_cairo_stroke (cairo_t *cr);
 void fancy_cairo_stroke_preserve (cairo_t *cr);
@@ -472,10 +472,10 @@ draw_text (cairo_t *cr,
            const char *font,
            const char *text)
 {
-  PangoContext *context;
-  PangoLayout *layout;
-  PangoLine *line;
-  PangoFontDescription *desc;
+  Pango2Context *context;
+  Pango2Layout *layout;
+  Pango2Line *line;
+  Pango2FontDescription *desc;
   cairo_font_options_t *font_options;
 
   font_options = cairo_font_options_create ();
@@ -486,20 +486,20 @@ draw_text (cairo_t *cr,
   cairo_set_font_options (cr, font_options);
   cairo_font_options_destroy (font_options);
 
-  context = pango_cairo_create_context (cr);
-  layout = pango_layout_new (context);
+  context = pango2_cairo_create_context (cr);
+  layout = pango2_layout_new (context);
   g_object_unref (context);
 
-  desc = pango_font_description_from_string (font);
-  pango_layout_set_font_description (layout, desc);
-  pango_font_description_free (desc);
+  desc = pango2_font_description_from_string (font);
+  pango2_layout_set_font_description (layout, desc);
+  pango2_font_description_free (desc);
 
-  pango_layout_set_text (layout, text, -1);
+  pango2_layout_set_text (layout, text, -1);
 
-  line = pango_lines_get_lines (pango_layout_get_lines (layout))[0];
+  line = pango2_lines_get_lines (pango2_layout_get_lines (layout))[0];
 
   cairo_move_to (cr, x, y);
-  pango_cairo_line_path (cr, line);
+  pango2_cairo_line_path (cr, line);
 
   g_object_unref (layout);
 }
@@ -612,7 +612,12 @@ int main (int argc, char **argv)
 
   cairo_destroy (cr);
 
+#ifdef CAIRO_HAS_PNG_FUNCTIONS
   status = cairo_surface_write_to_png (surface, filename);
+#else
+  status = CAIRO_STATUS_PNG_ERROR; /* Not technically correct, but... */
+#endif
+
   cairo_surface_destroy (surface);
 
   if (status != CAIRO_STATUS_SUCCESS)
