@@ -2,10 +2,10 @@
  * and compiled in a C++ program.
  */
 
-#include <pango/pango.h>
+#include <pango2/pango.h>
 
-#ifdef HAVE_CAIRO
-#include <pango/pangocairo.h>
+#if PANGO2_HAS_CAIRO
+#include <pango2/pangocairo.h>
 #endif
 
 int
