@@ -2,11 +2,11 @@
 #include <stdio.h>
 
 int
-main (int argc G_GNUC_UNUSED,
+main (int    argc G_GNUC_UNUSED,
       char **argv G_GNUC_UNUSED)
 {
   gunichar i;
-  gint j;
+  int j;
 
   /* Output all characters in the BMP twice, once directly
    * concatenated, once with spaces between them
@@ -17,7 +17,7 @@ main (int argc G_GNUC_UNUSED,
 	{
 	  if (g_unichar_validate (i))
 	    {
-	      gchar buffer[7];
+	      char buffer[7];
 	      int len = g_unichar_to_utf8 (i, buffer);
 	      buffer[len] = '\0';
 
