@@ -10,7 +10,7 @@
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
@@ -26,9 +26,9 @@
 #include <string.h>
 #include <time.h>
 
-#include <pango/pango-enum-types.h>
-#include <pango/pango-script.h>
-#include <pango/pango-types.h>
+#include <pango2/pango-enum-types.h>
+#include <pango2/pango-script.h>
+#include <pango2/pango-types.h>
 
 #include <fontconfig/fontconfig.h>
 
@@ -40,7 +40,7 @@ typedef struct {
 } ScriptInfo;
 
 typedef struct {
-  PangoLanguage *lang;
+  Pango2Language *lang;
   ScriptInfo scripts[MAX_SCRIPTS];
 } LangInfo;
 
@@ -71,7 +71,7 @@ static void fail (const char *format, ...)
 
 static void
 script_for_char (gunichar   ch,
-                 LangInfo  *info)
+		 LangInfo  *info)
 {
   GUnicodeScript script = g_unichar_get_script (ch);
   if (script != G_UNICODE_SCRIPT_COMMON &&
@@ -80,24 +80,24 @@ script_for_char (gunichar   ch,
       int j;
 
       if (script == G_UNICODE_SCRIPT_UNKNOWN)
-        {
-           g_message ("Script unknown for U+%04X", ch);
-           return;
-        }
+	{
+	   g_message ("Script unknown for U+%04X", ch);
+	   return;
+	}
 
       for (j = 0; j < MAX_SCRIPTS; j++)
-        {
-          if (info->scripts[j].script == script)
-            break;
-          if (info->scripts[j].script == G_UNICODE_SCRIPT_COMMON)
-            {
-              info->scripts[j].script = script;
-              break;
-            }
-        }
+	{
+	  if (info->scripts[j].script == script)
+	    break;
+	  if (info->scripts[j].script == G_UNICODE_SCRIPT_COMMON)
+	    {
+	      info->scripts[j].script = script;
+	      break;
+	    }
+	}
 
       if (j == MAX_SCRIPTS)
-        fail ("More than %d scripts found for %s.  Increase MAX_SCRIPTS.\n", MAX_SCRIPTS, pango_language_to_string (info->lang));
+	fail ("More than %d scripts found for %s.  Increase MAX_SCRIPTS.\n", MAX_SCRIPTS, pango2_language_to_string (info->lang));
 
       info->scripts[j].freq++;
     }
@@ -121,31 +121,31 @@ scripts_for_lang (LangInfo   *info)
     {
 
       for (i = 0; i < FC_CHARSET_MAP_SIZE; i++)
-        {
-          FcChar32  bits = map[i];
-          FcChar32  base = ucs4 + i * 32;
-          int b = 0;
-          bits = map[i];
-          while (bits)
-            {
-              if (bits & 1)
-                script_for_char (base + b, info);
+	{
+	  FcChar32  bits = map[i];
+	  FcChar32  base = ucs4 + i * 32;
+	  int b = 0;
+	  bits = map[i];
+	  while (bits)
+	    {
+	      if (bits & 1)
+		script_for_char (base + b, info);
 
-              bits >>= 1;
-              b++;
-            }
-        }
+	      bits >>= 1;
+	      b++;
+	    }
+	}
     }
 }
 
 static void
 do_lang (GArray        *script_array,
-         const FcChar8 *lang)
+	 const FcChar8 *lang)
 {
   LangInfo info;
   int j;
 
-  info.lang = pango_language_from_string ((const char *)lang);
+  info.lang = pango2_language_from_string ((const char *)lang);
 
   for (j = 0; j < MAX_SCRIPTS; j++)
     {
@@ -160,8 +160,8 @@ do_lang (GArray        *script_array,
 
 static int
 compare_script (gconstpointer a,
-                gconstpointer b,
-                gpointer      data)
+		gconstpointer b,
+		gpointer      data)
 {
   const ScriptInfo *info_a = a;
   const ScriptInfo *info_b = b;
@@ -190,13 +190,13 @@ compare_script (gconstpointer a,
 
 static int
 compare_lang (gconstpointer a,
-              gconstpointer b)
+	      gconstpointer b)
 {
   const LangInfo *info_a = a;
   const LangInfo *info_b = b;
 
-  return strcmp (pango_language_to_string (info_a->lang),
-                 pango_language_to_string (info_b->lang));
+  return strcmp (pango2_language_to_string (info_a->lang),
+		 pango2_language_to_string (info_b->lang));
 }
 
 int main (void)
@@ -238,17 +238,17 @@ int main (void)
       LangInfo *info = &g_array_index (script_array, LangInfo, i);
 
       max_lang_len = MAX (max_lang_len,
-                          (int)strlen (pango_language_to_string (info->lang)));
+			  (int)strlen (pango2_language_to_string (info->lang)));
 
-      g_sort_array (info->scripts,
-                    G_N_ELEMENTS (info->scripts),
-                    sizeof (info->scripts[0]),
-                    compare_script,
-                    info);
+      g_qsort_with_data (info->scripts,
+			 G_N_ELEMENTS (info->scripts),
+			 sizeof (info->scripts[0]), 
+			 compare_script,
+			 info);
 
       for (j = 0; j < MAX_SCRIPTS; j++)
         if (!info->scripts[j].freq)
-          break;
+	  break;
       
       max_script_len = MAX (max_script_len, j);
     }
@@ -259,53 +259,53 @@ int main (void)
   fc_version = FcGetVersion ();
 
   g_print ("/* pango-script-lang-table.h:\n"
-           " * \n"
-           " * Generated by %s\n"
-           " * Date: %s\n"
-           " * Source: fontconfig-%d.%d.%d\n"
-           " * \n"
-           " * Do not edit.\n"
-           " */\n",
-           __FILE__,
-           date_str,
-           fc_version / 10000, (fc_version / 100) % 100, fc_version % 100);
+	   " * \n"
+	   " * Generated by %s\n"
+	   " * Date: %s\n"
+	   " * Source: fontconfig-%d.%d.%d\n"
+	   " * \n"
+	   " * Do not edit.\n"
+	   " */\n",
+	   __FILE__,
+	   date_str,
+	   fc_version / 10000, (fc_version / 100) % 100, fc_version % 100);
 
   g_print ("typedef struct _PangoScriptForLang {\n"
-           "  const char lang[%d];\n"
-           "  GUnicodeScript scripts[%d];\n"
-           "} PangoScriptForLang;\n"
-           "\n"
-           "static const PangoScriptForLang pango_script_for_lang[] = {\n",
-           max_lang_len + 1,
-           max_script_len);
+	   "  const char lang[%d];\n"
+	   "  GUnicodeScript scripts[%d];\n"
+	   "} PangoScriptForLang;\n"
+	   "\n"
+	   "static const PangoScriptForLang pango_script_for_lang[] = {\n",
+	   max_lang_len + 1,
+	   max_script_len);
   
   for (i = 0; i < script_array->len; i++)
     {
       LangInfo *info = &g_array_index (script_array, LangInfo, i);
       
       g_print ("  { \"%s\", %*s{ ",
-               pango_language_to_string (info->lang),
-               (int)(max_lang_len - strlen (pango_language_to_string (info->lang))), "");
+	       pango2_language_to_string (info->lang),
+	       (int)(max_lang_len - strlen (pango2_language_to_string (info->lang))), "");
       for (j = 0; j < MAX_SCRIPTS; j++)
-        {
-          if (!info->scripts[j].freq)
-            {
-              /* Avoid generating code with empty arrays */
-              if (j == 0)
-                g_print ("0");
+	{
+	  if (!info->scripts[j].freq)
+	    {
+	      /* Avoid generating code with empty arrays */
+	      if (j == 0)
+	        g_print ("0");
 
-              break;
-            }
+	      break;
+	    }
 
-          if (j != 0)
-            g_print (", ");
-          g_print ("%s/*%d*/",
-                   get_script_name (info->scripts[j].script),
-                   info->scripts[j].freq);
-        }
+	  if (j != 0)
+	    g_print (", ");
+	  g_print ("%s/*%d*/",
+		   get_script_name (info->scripts[j].script),
+		   info->scripts[j].freq);
+	}
       g_print (" } }");
       if (i + 1 != script_array->len)
-        g_print (",");
+	g_print (",");
       g_print ("\n");
     }
 
